@@ -23,7 +23,6 @@
 #include "qtractorAudioEngine.h"
 #include "qtractorAudioMonitor.h"
 #include "qtractorAudioBuffer.h"
-#include "qtractorAudioClip.h"
 
 #include "qtractorSession.h"
 
@@ -36,8 +35,6 @@
 #include "qtractorPlugin.h"
 #include "qtractorClip.h"
 
-#include "qtractorCurveFile.h"
-
 #include "qtractorMainForm.h"
 
 #ifdef CONFIG_VST3
@@ -66,6 +63,13 @@
 #include <QProgressBar>
 #include <QDomDocument>
 
+
+// Sensible defaults.
+#define SAMPLE_RATE 44100
+#define BUFFER_SIZE 1024
+#define BLOCK_SIZE  64
+
+
 #if defined(__SSE__)
 
 #include <xmmintrin.h>
@@ -498,10 +502,11 @@ qtractorAudioEngine::qtractorAudioEngine ( qtractorSession *pSession )
 {
 	m_pJackClient = nullptr;
 
-	m_iSampleRate = 44100;	// A sensible default, always.
+	m_iSampleRate = SAMPLE_RATE;	// A sensible default, always.
 	m_iBufferSize = 0;
-	m_iBufferSizeEx = 1024;	// Another sensible default, sometimes.
+	m_iBufferSizeEx = BUFFER_SIZE;	// Another sensible default, sometimes.
 	m_iBufferOffset = 0;
+	m_iBlockSize = BLOCK_SIZE;		// Yet another sensible default, always.
 
 	m_bMasterAutoConnect = true;
 
@@ -553,6 +558,9 @@ qtractorAudioEngine::qtractorAudioEngine ( qtractorSession *pSession )
 	// JACK timebase mode control.
 	m_bTimebase = true;
 	m_iTimebase = 0;
+
+	// Time(base)/BBT time info.
+	::memset(&m_timeInfo, 0, sizeof(TimeInfo));
 }
 
 
@@ -581,10 +589,13 @@ void qtractorAudioEngine::notifyPortEvent (void)
 
 void qtractorAudioEngine::notifyBuffEvent ( unsigned int iBufferSize )
 {
-	if (m_iBufferSizeEx < iBufferSize)
+	if (m_iBufferSizeEx < iBufferSize) {
 		m_proxy.notifyBuffEvent(iBufferSize);
-	else
+	} else {
 		m_iBufferSize = iBufferSize;
+		if (m_iBlockSize < m_iBufferSize)
+			m_iBlockSize = m_iBufferSize;
+	}
 }
 
 void qtractorAudioEngine::notifySessEvent ( void *pvSessionArg )
@@ -616,6 +627,7 @@ unsigned int qtractorAudioEngine::sampleRate (void) const
 	return m_iSampleRate;
 }
 
+
 // Buffer size accessors.
 unsigned int qtractorAudioEngine::bufferSize (void) const
 {
@@ -635,6 +647,13 @@ unsigned int qtractorAudioEngine::bufferOffset (void) const
 }
 
 
+// Block-stride size (in frames) accessor.
+unsigned int qtractorAudioEngine::blockSize (void) const
+{
+	return m_iBlockSize;
+}
+
+
 // Audio (Master) bus defaults accessors.
 void qtractorAudioEngine::setMasterAutoConnect ( bool bMasterAutoConnect )
 {
@@ -685,10 +704,17 @@ bool qtractorAudioEngine::init (void)
 	m_iSampleRate = jack_get_sample_rate(m_pJackClient);
 	m_iBufferSize = jack_get_buffer_size(m_pJackClient);
 
+	// Block-stride size changes...
+	m_iBlockSize = BLOCK_SIZE;
+	if (m_iBlockSize < m_iBufferSize)
+		m_iBlockSize = m_iBufferSize;
+
 	// Guard for buffer size changes...
 	const unsigned int iBufferSizeEx = (m_iBufferSize << 1);
 	if (m_iBufferSizeEx < iBufferSizeEx)
 		m_iBufferSizeEx = iBufferSizeEx;
+	if (m_iBufferSizeEx < m_iBlockSize)
+		m_iBufferSizeEx = m_iBlockSize;
 
 	// ATTN: Second is setting proper session client name.
 	pSession->setClientName(
@@ -786,6 +812,9 @@ bool qtractorAudioEngine::activate (void)
 		qtractorAudioEngine_property_change, this);
 #endif
 
+	// Initialize time(base) information for sure...
+	updateTimeInfo(0);
+
 	// Reset all dependable monitoring...
 	resetAllMonitors();
 
@@ -935,6 +964,15 @@ void qtractorAudioEngine::clean (void)
 }
 
 
+// Whether we're in the audio/real-time thread...
+static thread_local bool g_bProcessing = false;
+
+bool qtractorAudioEngine::isProcessing (void)
+{
+	return g_bProcessing;
+}
+
+
 // Process cycle executive.
 int qtractorAudioEngine::process ( unsigned int nframes )
 {
@@ -966,6 +1004,9 @@ int qtractorAudioEngine::process ( unsigned int nframes )
 	if (!pSession->acquire())
 		return 0;
 
+	// We're in the audio/real-time thread...
+	g_bProcessing = true;
+
 	// Track whether audio output buses
 	// buses needs monitoring while idle...
 	int iOutputBus = 0;
@@ -1013,34 +1054,23 @@ int qtractorAudioEngine::process ( unsigned int nframes )
 		ATOMIC_SET(&m_playerLock, 0);
 	}
 
-#ifdef CONFIG_VST3
-	qtractorVst3Plugin::updateTime(this);
-#endif
-#ifdef CONFIG_CLAP
-	qtractorClapPlugin::updateTime(this);
-#endif
-#ifdef CONFIG_LV2
-#ifdef CONFIG_LV2_TIME
-	qtractorLv2Plugin::updateTime(this);
-#endif
-#endif
+	// This the legal process cycle frame range...
+	unsigned long iFrameStart = pAudioCursor->frame();
+	unsigned long iFrameEnd   = iFrameStart + nframes;
 
-	// MIDI plugin manager processing...
-	qtractorMidiManager *pMidiManager
-		= pSession->midiManagers().first();
-	if (pMidiManager) {
-		const unsigned long iFrameTimeStart = pAudioCursor->frameTime();
-		const unsigned long iFrameTimeEnd   = iFrameTimeStart + nframes;
+	// Don't go any further, if not playing.
+	if (!isPlaying()) {
+		// Update time(base) info...
+		updateTimeInfo(iFrameStart);
+		// MIDI managers plugin processing...
+		qtractorMidiManager *pMidiManager
+			= pSession->midiManagers().first();
 		while (pMidiManager) {
-			pMidiManager->process(iFrameTimeStart, iFrameTimeEnd);
+			pMidiManager->process(iFrameStart, iFrameEnd);
 			if (!pMidiManager->isAudioOutputBus())
 				++iOutputBus;
 			pMidiManager = pMidiManager->next();
 		}
-	}
-
-	// Don't go any further, if not playing.
-	if (!isPlaying()) {
 		// Do the idle processing...
 		for (qtractorTrack *pTrack = pSession->tracks().first();
 				pTrack; pTrack = pTrack->next()) {
@@ -1086,14 +1116,11 @@ int qtractorAudioEngine::process ( unsigned int nframes )
 		}
 		// Done as idle...
 		pAudioCursor->process(nframes);
+		g_bProcessing = false;
 		pSession->release();
 		return 0;
 	}
 
-	// This the legal process cycle frame range...
-	unsigned long iFrameStart = pAudioCursor->frame();
-	unsigned long iFrameEnd   = iFrameStart + nframes;
-
 	// Metronome stuff...
 	if (m_bMetronome && m_pMetroBus && iFrameEnd > m_iMetroBeatStart) {
 		qtractorTimeScale::Cursor& cursor = pSession->timeScale()->cursor();
@@ -1118,30 +1145,63 @@ int qtractorAudioEngine::process ( unsigned int nframes )
 			m_pMetroBus->process_commit(nframes);
 	}
 
-	// Split processing, in case we're looping...
-	if (pSession->isLooping()) {
-		const unsigned long iLoopEnd = pSession->loopEnd();
-		if (iFrameStart < iLoopEnd) {
-			// Loop-length might be shorter than the buffer-period...
-			while (iFrameEnd >= iLoopEnd + nframes) {
-				// Process the remaining until end-of-loop...
-				pSession->process(pAudioCursor, iFrameStart, iLoopEnd);
-				m_iBufferOffset += (iLoopEnd - iFrameStart);
-				// Reset to start-of-loop...
-				iFrameStart = pSession->loopStart();
-				iFrameEnd   = iFrameStart + (iFrameEnd - iLoopEnd);
-				// Set to new transport location...
-				if (m_transportMode & qtractorBus::Output)
-					jack_transport_locate(m_pJackClient, iFrameStart);
-				pAudioCursor->seek(iFrameStart);
+	// MIDI managers plugin frame time...
+	const unsigned long iFrameTimeStart = pAudioCursor->frameTime();
+	const unsigned long iFrameTimeEnd   = iFrameTimeStart + nframes;
+
+	unsigned int nframes2 = m_iBlockSize;
+	if (nframes2 > nframes)
+		nframes2 = nframes;
+
+	unsigned long iFrameTimeStart2 = iFrameTimeStart;
+
+	for (unsigned long iFrameStart2 = iFrameStart;
+			iFrameStart2 < iFrameEnd; iFrameStart2 += nframes2) {
+		// Update time(base) info...
+		updateTimeInfo(iFrameStart2);
+		// MIDI managers plugin processing...
+		unsigned long iFrameTimeEnd2 = iFrameTimeStart2 + nframes2;
+		if (iFrameTimeEnd2 > iFrameTimeEnd)
+			iFrameTimeEnd2 = iFrameTimeEnd;
+		qtractorMidiManager *pMidiManager
+			= pSession->midiManagers().first();
+		while (pMidiManager) {
+			pMidiManager->process(iFrameTimeStart2, iFrameTimeEnd2);
+			if (!pMidiManager->isAudioOutputBus())
+				++iOutputBus;
+			pMidiManager = pMidiManager->next();
+		}
+		iFrameTimeStart2 += nframes2;
+		// Main processing...
+		unsigned long iFrameEnd2 = iFrameStart2 + nframes2;
+		if (iFrameEnd2 > iFrameEnd)
+			iFrameEnd2 = iFrameEnd;
+		// Split processing, in case we're looping...
+		if (pSession->isLooping()) {
+			const unsigned long iLoopEnd = pSession->loopEnd();
+			if (iFrameStart2 < iLoopEnd) {
+				// Loop-length might be shorter than the buffer-period...
+				while (iFrameEnd2 >= iLoopEnd + nframes2) {
+					// Process the remaining until end-of-loop...
+					pSession->process(pAudioCursor, iFrameStart2, iLoopEnd);
+					m_iBufferOffset += (iLoopEnd - iFrameStart2);
+					// Reset to start-of-loop...
+					iFrameStart2 = pSession->loopStart();
+					iFrameEnd2   = iFrameStart2 + (iFrameEnd2 - iLoopEnd);
+					// Set to new transport location...
+					if (m_transportMode & qtractorBus::Output)
+						jack_transport_locate(m_pJackClient, iFrameStart2);
+					pAudioCursor->seek(iFrameStart2);
+					// Update time(base) info...
+					updateTimeInfo(iFrameStart2);
+				}
 			}
 		}
+		// Regular range playback...
+		pSession->process(pAudioCursor, iFrameStart2, iFrameEnd2);
+		m_iBufferOffset += (iFrameEnd2 - iFrameStart2);
 	}
 
-	// Regular range playback...
-	pSession->process(pAudioCursor, iFrameStart, iFrameEnd);
-	m_iBufferOffset += (iFrameEnd - iFrameStart);
-
 	// Commit current audio buses...
 	for (pBus = buses().first(); pBus; pBus = pBus->next()) {
 		pAudioBus = static_cast<qtractorAudioBus *> (pBus);
@@ -1177,6 +1237,7 @@ int qtractorAudioEngine::process ( unsigned int nframes )
 	pSession->midiEngine()->sync();
 
 	// Release RT-safeness lock...
+	g_bProcessing = false;
 	pSession->release();
 
 	// Process session stuff...
@@ -1220,30 +1281,38 @@ void qtractorAudioEngine::process_export ( unsigned int nframes )
 	const unsigned long iFrameStart = pAudioCursor->frame();
 	const unsigned long iFrameEnd   = iFrameStart + nframes;
 
+	unsigned int nframes2 = m_iBlockSize;
+	if (nframes2 > nframes)
+		nframes2 = nframes;
+
 	// Write output bus buffers to export audio file...
 	if (iFrameStart < m_iExportEnd) {
 		// Prepare mix-down buffer...
 		m_pExportBuffer->process_prepare(nframes);
-		// Force/sync every audio clip approaching...
-	#ifdef CONFIG_LV2
-	#ifdef CONFIG_LV2_TIME
-		qtractorLv2Plugin::updateTime(this);
-	#endif
-	#endif
-		// Perform all tracks processing...
-		int iTrack = 0;
-		for (qtractorTrack *pTrack = pSession->tracks().first();
-				pTrack; pTrack = pTrack->next()) {
-			pTrack->process_export(pAudioCursor->clip(iTrack),
-				iFrameStart, iFrameEnd);
-			++iTrack;
-		}
-		// MIDI plugin manager processing...
-		qtractorMidiManager *pMidiManager
-			= pSession->midiManagers().first();
-		while (pMidiManager) {
-			pMidiManager->process(iFrameStart, iFrameEnd);
-			pMidiManager = pMidiManager->next();
+		for (unsigned long iFrameStart2 = iFrameStart;
+				iFrameStart2 < iFrameEnd; iFrameStart2 += nframes2) {
+			// Update time(base) info...
+			updateTimeInfo(iFrameStart2);
+			// Main processing...
+			unsigned long iFrameEnd2 = iFrameStart2 + nframes2;
+			if (iFrameEnd2 > iFrameEnd)
+				iFrameEnd2 = iFrameEnd;
+			// MIDI managers plugin processing...
+			qtractorMidiManager *pMidiManager
+				= pSession->midiManagers().first();
+			while (pMidiManager) {
+				pMidiManager->process(iFrameStart2, iFrameEnd2);
+				pMidiManager = pMidiManager->next();
+			}
+			// Perform all tracks processing...
+			int iTrack = 0;
+			for (qtractorTrack *pTrack = pSession->tracks().first();
+					pTrack; pTrack = pTrack->next()) {
+				pTrack->process_export(pAudioCursor->clip(iTrack),
+					iFrameStart2, iFrameEnd2);
+				++iTrack;
+			}
+			m_iBufferOffset += (iFrameEnd2 - iFrameStart2);
 		}
 		// Prepare advance for next cycle...
 		pAudioCursor->seek(iFrameEnd);
@@ -1302,9 +1371,53 @@ void qtractorAudioEngine::process_export ( unsigned int nframes )
 }
 
 
+// Update time(base)/BBT info.
+void qtractorAudioEngine::updateTimeInfo ( unsigned long iFrame )
+{
+	qtractorSession *pSession = session();
+	qtractorTimeScale::Cursor& cursor = pSession->timeScale()->cursor();
+	qtractorTimeScale::Node *pNode = cursor.seekFrame(iFrame);
+
+	m_timeInfo.frame = iFrame;
+	m_timeInfo.playing = (isPlaying() || isFreewheel());
+	m_timeInfo.sampleRate = sampleRate();
+	m_timeInfo.tempo = pNode->tempo;
+	m_timeInfo.beatsPerBar  = pNode->beatsPerBar;
+	m_timeInfo.ticksPerBeat = pNode->ticksPerBeat;
+	m_timeInfo.beatType = (1 << pNode->beatDivisor);
+	m_timeInfo.beats = float(pNode->beat);
+	m_timeInfo.tick = pNode->tickFromFrame(iFrame) - pNode->tick;
+	const float beats = float(m_timeInfo.tick) / float(m_timeInfo.ticksPerBeat);
+	m_timeInfo.beats += beats;
+	m_timeInfo.bar = pNode->bar + (unsigned short) beats / m_timeInfo.beatsPerBar;
+	m_timeInfo.beat = (unsigned int) m_timeInfo.beats;
+	if (m_timeInfo.tick >= (unsigned long) m_timeInfo.ticksPerBeat)
+		m_timeInfo.tick -= (unsigned long) (m_timeInfo.beat * m_timeInfo.ticksPerBeat);
+	if (m_timeInfo.beat >= (unsigned int) m_timeInfo.beatsPerBar)
+		m_timeInfo.beat -= (unsigned int) (m_timeInfo.bar * m_timeInfo.beatsPerBar);
+	m_timeInfo.barBeats = ::truncf(m_timeInfo.beats) - float(m_timeInfo.beat);
+
+	++m_timeInfo.bar;
+	++m_timeInfo.beat;
+
+#ifdef CONFIG_VST3
+	qtractorVst3Plugin::updateTime(this);
+#endif
+#ifdef CONFIG_CLAP
+	qtractorClapPlugin::updateTime(this);
+#endif
+#ifdef CONFIG_LV2
+#ifdef CONFIG_LV2_TIME
+	qtractorLv2Plugin::updateTime(this);
+#endif
+#endif
+}
+
+
 // JACK timebase master callback.
 void qtractorAudioEngine::timebase ( jack_position_t *pPos, int iNewPos )
 {
+#if 0//QTRACTOR_TIMEBASE_OLD
 	qtractorSession *pSession = session();
 	qtractorTimeScale::Cursor& cursor = pSession->timeScale()->cursor();
 	qtractorTimeScale::Node *pNode = cursor.seekFrame(pPos->frame);
@@ -1329,7 +1442,21 @@ void qtractorAudioEngine::timebase ( jack_position_t *pPos, int iNewPos )
 	pPos->ticks_per_beat   = pNode->ticksPerBeat;
 	pPos->beats_per_minute = pNode->tempo;
 	pPos->beat_type        = float(1 << pNode->beatDivisor);
-
+#else
+	// Check for major gaps to last known JACK transport position...
+	if (qAbs(long(pPos->frame) - long(m_timeInfo.frame)) > long(m_iBufferSize))
+		updateTimeInfo(pPos->frame);
+	// Time frame code in bars.beats.ticks ...
+	pPos->valid = JackPositionBBT;
+	pPos->bar   = m_timeInfo.bar;
+	pPos->beat  = m_timeInfo.beat;
+	pPos->tick  = m_timeInfo.tick;
+	// Keep current tempo (BPM)...
+	pPos->beats_per_bar    = m_timeInfo.beatsPerBar;
+	pPos->ticks_per_beat   = m_timeInfo.ticksPerBeat;
+	pPos->beats_per_minute = m_timeInfo.tempo;
+	pPos->beat_type        = m_timeInfo.beatType;
+#endif
 	// Tell that we've been here...
 	if (iNewPos) ++m_iTimebase;
 }
