@@ -136,6 +136,9 @@ public:
 	// Buffer offset accessor.
 	unsigned int bufferOffset() const;
 
+	// Block-stride size (in frames) accessor.
+	unsigned int blockSize() const;
+
 	// Audio (Master) bus defaults accessors.
 	void setMasterAutoConnect(bool bMasterAutoConnect);
 	bool isMasterAutoConnect() const;
@@ -251,7 +254,7 @@ public:
 		bool           playing;
 		unsigned int   sampleRate;
 		float          tempo;
-		unsigned short ticksPerBeat;
+		unsigned int   ticksPerBeat;
 		unsigned short beatsPerBar;
 		unsigned short beatType;
 		float          beats;
@@ -316,6 +319,9 @@ private:
 	// careful for proper loop concatenation.
 	unsigned int m_iBufferOffset;
 
+	// Block-stride size (in frames).
+	unsigned int m_iBlockSize;
+
 	// Audio (Master) bus defaults.
 	bool m_bMasterAutoConnect;
 
