@@ -1,7 +1,7 @@
 // qtractorBusForm.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2019, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2020, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -38,7 +38,7 @@ class qtractorBusForm : public QDialog
 public:
 
 	// Constructor.
-	qtractorBusForm(QWidget *pParent = 0, Qt::WindowFlags wflags = 0);
+	qtractorBusForm(QWidget *pParent = nullptr);
 
 	void setBus(qtractorBus *pBus);
 	qtractorBus *bus();
