@@ -188,9 +188,9 @@ qtractorOptionsForm::qtractorOptionsForm ( QWidget *pParent )
 	m_ui.PluginTypeComboBox->addItem(
 		qtractorPluginType::textFromHint(qtractorPluginType::Dssi));
 #endif
-#ifdef CONFIG_VST
+#ifdef CONFIG_VST2
 	m_ui.PluginTypeComboBox->addItem(
-		qtractorPluginType::textFromHint(qtractorPluginType::Vst));
+		qtractorPluginType::textFromHint(qtractorPluginType::Vst2));
 #endif
 #ifdef CONFIG_VST3
 	m_ui.PluginTypeComboBox->addItem(
@@ -217,7 +217,7 @@ qtractorOptionsForm::qtractorOptionsForm ( QWidget *pParent )
 
 	m_iDirtyLadspaPaths = 0;
 	m_iDirtyDssiPaths   = 0;
-	m_iDirtyVstPaths    = 0;
+	m_iDirtyVst2Paths   = 0;
 	m_iDirtyVst3Paths   = 0;
 	m_iDirtyClapPaths   = 0;
 	m_iDirtyLv2Paths    = 0;
@@ -478,10 +478,10 @@ qtractorOptionsForm::qtractorOptionsForm ( QWidget *pParent )
 	QObject::connect(m_ui.Lv2PresetDirComboBox,
 		SIGNAL(editTextChanged(const QString&)),
 		SLOT(pluginPathsChanged()));
-#endif
 	QObject::connect(m_ui.Lv2PresetDirToolButton,
 		SIGNAL(clicked()),
 		SLOT(chooseLv2PresetDir()));
+#endif
 	QObject::connect(m_ui.AudioOutputBusCheckBox,
 		SIGNAL(stateChanged(int)),
 		SLOT(changed()));
@@ -730,7 +730,7 @@ void qtractorOptionsForm::setOptions ( qtractorOptions *pOptions )
 	// Plugin path initialization...
 	m_ladspaPaths = m_pOptions->ladspaPaths;
 	m_dssiPaths   = m_pOptions->dssiPaths;
-	m_vstPaths    = m_pOptions->vstPaths;
+	m_vst2Paths   = m_pOptions->vst2Paths;
 	m_vst3Paths   = m_pOptions->vst3Paths;
 	m_lv2Paths    = m_pOptions->lv2Paths;
 
@@ -746,9 +746,9 @@ void qtractorOptionsForm::setOptions ( qtractorOptions *pOptions )
 		if (m_dssiPaths.isEmpty())
 			m_dssiPaths = pPluginFactory->pluginPaths(qtractorPluginType::Dssi);
 	#endif
-	#ifdef CONFIG_VST
-		if (m_vstPaths.isEmpty())
-			m_vstPaths = pPluginFactory->pluginPaths(qtractorPluginType::Vst);
+	#ifdef CONFIG_VST2
+		if (m_vst2Paths.isEmpty())
+			m_vst2Paths = pPluginFactory->pluginPaths(qtractorPluginType::Vst2);
 	#endif
 	#ifdef CONFIG_VST3
 		if (m_vst3Paths.isEmpty())
@@ -778,6 +778,7 @@ void qtractorOptionsForm::setOptions ( qtractorOptions *pOptions )
 
 	m_ui.PluginBlacklistWidget->clear();
 	m_ui.PluginBlacklistWidget->addItems(pPluginFactory->blacklist());
+	m_ui.PluginBlacklistComboBox->setEditText(QString());
 
 	choosePluginType(iPluginType);
 	selectPluginBlacklist();
@@ -791,7 +792,7 @@ void qtractorOptionsForm::setOptions ( qtractorOptions *pOptions )
 
 	m_iDirtyLadspaPaths = 0;
 	m_iDirtyDssiPaths   = 0;
-	m_iDirtyVstPaths    = 0;
+	m_iDirtyVst2Paths   = 0;
 	m_iDirtyVst3Paths   = 0;
 	m_iDirtyClapPaths   = 0;
 	m_iDirtyLv2Paths    = 0;
@@ -895,8 +896,8 @@ void qtractorOptionsForm::accept (void)
 			m_pOptions->ladspaPaths      = m_ladspaPaths;
 		if (m_iDirtyDssiPaths > 0)
 			m_pOptions->dssiPaths        = m_dssiPaths;
-		if (m_iDirtyVstPaths > 0)
-			m_pOptions->vstPaths         = m_vstPaths;
+		if (m_iDirtyVst2Paths > 0)
+			m_pOptions->vst2Paths        = m_vst2Paths;
 		if (m_iDirtyVst3Paths > 0)
 			m_pOptions->vst3Paths        = m_vst3Paths;
 		if (m_iDirtyClapPaths > 0)
@@ -954,7 +955,7 @@ void qtractorOptionsForm::accept (void)
 		if (pPluginFactory) {
 			if (m_iDirtyLadspaPaths > 0 ||
 				m_iDirtyDssiPaths   > 0 ||
-				m_iDirtyVstPaths    > 0 ||
+				m_iDirtyVst2Paths   > 0 ||
 				m_iDirtyVst3Paths   > 0 ||
 				m_iDirtyClapPaths   > 0 ||
 				m_iDirtyLv2Paths    > 0) {
@@ -1331,8 +1332,8 @@ void qtractorOptionsForm::choosePluginType ( int iPluginType )
 	case qtractorPluginType::Dssi:
 		paths = m_dssiPaths;
 		break;
-	case qtractorPluginType::Vst:
-		paths = m_vstPaths;
+	case qtractorPluginType::Vst2:
+		paths = m_vst2Paths;
 		break;
 	case qtractorPluginType::Vst3:
 		paths = m_vst3Paths;
@@ -1430,9 +1431,9 @@ void qtractorOptionsForm::addPluginPath (void)
 		m_dssiPaths.append(sPluginPath);
 		++m_iDirtyDssiPaths;
 		break;
-	case qtractorPluginType::Vst:
-		m_vstPaths.append(sPluginPath);
-		++m_iDirtyVstPaths;
+	case qtractorPluginType::Vst2:
+		m_vst2Paths.append(sPluginPath);
+		++m_iDirtyVst2Paths;
 		break;
 	case qtractorPluginType::Vst3:
 		m_vst3Paths.append(sPluginPath);
@@ -1498,9 +1499,9 @@ void qtractorOptionsForm::removePluginPath (void)
 		m_dssiPaths.removeAt(iPluginPath);
 		++m_iDirtyDssiPaths;
 		break;
-	case qtractorPluginType::Vst:
-		m_vstPaths.removeAt(iPluginPath);
-		++m_iDirtyVstPaths;
+	case qtractorPluginType::Vst2:
+		m_vst2Paths.removeAt(iPluginPath);
+		++m_iDirtyVst2Paths;
 		break;
 	case qtractorPluginType::Vst3:
 		m_vst3Paths.removeAt(iPluginPath);
@@ -1549,10 +1550,10 @@ void qtractorOptionsForm::moveUpPluginPath (void)
 		m_dssiPaths.insert(iPluginPath - 1, sPluginPath);
 		++m_iDirtyDssiPaths;
 		break;
-	case qtractorPluginType::Vst:
-		sPluginPath = m_vstPaths.takeAt(iPluginPath);
-		m_vstPaths.insert(iPluginPath - 1, sPluginPath);
-		++m_iDirtyVstPaths;
+	case qtractorPluginType::Vst2:
+		sPluginPath = m_vst2Paths.takeAt(iPluginPath);
+		m_vst2Paths.insert(iPluginPath - 1, sPluginPath);
+		++m_iDirtyVst2Paths;
 		break;
 	case qtractorPluginType::Vst3:
 		sPluginPath = m_vst3Paths.takeAt(iPluginPath);
@@ -1608,10 +1609,10 @@ void qtractorOptionsForm::moveDownPluginPath (void)
 		m_dssiPaths.insert(iPluginPath + 1, sPluginPath);
 		++m_iDirtyDssiPaths;
 		break;
-	case qtractorPluginType::Vst:
-		sPluginPath = m_vstPaths.takeAt(iPluginPath);
-		m_vstPaths.insert(iPluginPath + 1, sPluginPath);
-		++m_iDirtyVstPaths;
+	case qtractorPluginType::Vst2:
+		sPluginPath = m_vst2Paths.takeAt(iPluginPath);
+		m_vst2Paths.insert(iPluginPath + 1, sPluginPath);
+		++m_iDirtyVst2Paths;
 		break;
 	case qtractorPluginType::Vst3:
 		sPluginPath = m_vst3Paths.takeAt(iPluginPath);
@@ -1704,12 +1705,17 @@ void qtractorOptionsForm::choosePluginBlacklist (void)
 {
 	QString sFilename;
 
-	const QString  sExt("so");
 	const QString& sTitle
 		= tr("Plug-in Blacklist");
 
+	QStringList exts;
+	exts.append("so");
+#ifdef CONFIG_CLAP
+	exts.append("clap");
+#endif
+
 	QStringList filters;
-	filters.append(tr("Plug-in files (*.%1)").arg(sExt));
+	filters.append(tr("Plug-in files (*.%1)").arg(exts.join(" *.")));
 	filters.append(tr("All files (*.*)"));
 	const QString& sFilter = filters.join(";;");
 
@@ -1785,7 +1791,8 @@ void qtractorOptionsForm::selectPluginBlacklist (void)
 		= m_ui.PluginBlacklistWidget->currentRow();
 
 	m_ui.PluginBlacklistRemoveToolButton->setEnabled(iBlacklist >= 0);
-	m_ui.PluginBlacklistClearToolButton->setEnabled(iBlacklist >= 0);
+	m_ui.PluginBlacklistClearToolButton->setEnabled(
+		m_ui.PluginBlacklistWidget->count() > 0);
 }
 
 
