@@ -1,7 +1,7 @@
 // qtractorPluginForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2021, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2022, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -173,9 +173,13 @@ void qtractorPluginForm::setPlugin ( qtractorPlugin *pPlugin )
 		m_pPlugin->activateObserver());
 
 	qtractorPluginType *pType = m_pPlugin->type();
-	const bool bVstPlugin = (pType->typeHint() == qtractorPluginType::Vst);
-	const int MaxRowsPerPage    = (bVstPlugin ? 12 : 8);
-	const int MaxColumnsPerPage = (bVstPlugin ?  2 : 3);
+	const qtractorPluginType::Hint typeHint = pType->typeHint();
+	const bool bTwoColumnPage
+		= (typeHint == qtractorPluginType::Vst2
+		|| typeHint == qtractorPluginType::Vst3
+		|| typeHint == qtractorPluginType::Clap);
+	const int MaxRowsPerPage    = (bTwoColumnPage ? 12 : 8);
+	const int MaxColumnsPerPage = (bTwoColumnPage ?  2 : 3);
 	const int MaxItemsPerPage   = MaxRowsPerPage * MaxColumnsPerPage;
 
 	const qtractorPlugin::Params& params = m_pPlugin->params();
@@ -289,7 +293,7 @@ void qtractorPluginForm::setPlugin ( qtractorPlugin *pPlugin )
 		toggleEditor(m_pPlugin->isEditorVisible());
 
 	// Show insert tool options...
-	const bool bInsertPlugin = (pType->typeHint() == qtractorPluginType::Insert);
+	const bool bInsertPlugin = (typeHint == qtractorPluginType::Insert);
 	if (bInsertPlugin) {
 		if (pType->index() > 0) {
 			m_ui.SendsToolButton->setIcon(QIcon(":/images/itemAudioPortOut.png"));
@@ -303,7 +307,7 @@ void qtractorPluginForm::setPlugin ( qtractorPlugin *pPlugin )
 	m_ui.ReturnsToolButton->setVisible(bInsertPlugin);
 
 	// Show aux-send tool options...
-	const bool bAuxSendPlugin = (pType->typeHint() == qtractorPluginType::AuxSend);
+	const bool bAuxSendPlugin = (typeHint == qtractorPluginType::AuxSend);
 	m_ui.AuxSendBusNameComboBox->setVisible(bAuxSendPlugin);
 	m_ui.AuxSendBusNameLabel->setVisible(bAuxSendPlugin);
 	m_ui.AuxSendBusNameToolButton->setVisible(bAuxSendPlugin);
@@ -318,7 +322,7 @@ void qtractorPluginForm::setPlugin ( qtractorPlugin *pPlugin )
 	// About page...
 	m_ui.NameTextLabel->setText(pType->name());
 	m_ui.TypeHintTextLabel->setText(
-		qtractorPluginType::textFromHint(pType->typeHint()));
+		qtractorPluginType::textFromHint(typeHint));
 	QString sAboutText = pType->aboutText();
 	sAboutText += '\n';
 	sAboutText += '\n';
@@ -535,8 +539,8 @@ void qtractorPluginForm::openPresetSlot (void)
 		return;
 
 	qtractorPluginType *pType = m_pPlugin->type();
-	const bool bVstPlugin = (pType->typeHint() == qtractorPluginType::Vst);
-	if (!pType->isConfigure() && !bVstPlugin)
+	const bool bVst2Plugin = (pType->typeHint() == qtractorPluginType::Vst2);
+	if (!pType->isConfigure() && !bVst2Plugin)
 		return;
 
 	if (m_iUpdate > 0)
@@ -553,7 +557,7 @@ void qtractorPluginForm::openPresetSlot (void)
 	// Prompt if file does not currently exist...
 	const QString sExt("qtx");
 	QStringList exts(sExt);
-	if (bVstPlugin) {
+	if (bVst2Plugin) {
 		exts.append("fxp");
 		exts.append("fxb");
 	}
@@ -641,13 +645,13 @@ void qtractorPluginForm::savePresetSlot (void)
 	settings.beginGroup(m_pPlugin->presetGroup());
 	// Which mode of preset?
 	qtractorPluginType *pType = m_pPlugin->type();
-	const bool bVstPlugin = (pType->typeHint() == qtractorPluginType::Vst);
-	if (pType->isConfigure() || bVstPlugin) {
+	const bool bVst2Plugin = (pType->typeHint() == qtractorPluginType::Vst2);
+	if (pType->isConfigure() || bVst2Plugin) {
 		// Sure, we'll have something complex enough
 		// to make it save into an external file...
 		const QString sExt("qtx");
 		QStringList exts(sExt);
-		if (bVstPlugin) { exts.append("fxp"); exts.append("fxb"); }
+		if (bVst2Plugin) { exts.append("fxp"); exts.append("fxb"); }
 		QFileInfo fi(settings.value(sPreset).toString());
 		if (!fi.exists() || !fi.isFile())
 			fi.setFile(QDir(pOptions->sPresetDir),
@@ -1008,7 +1012,7 @@ void qtractorPluginForm::refresh (void)
 void qtractorPluginForm::stabilize (void)
 {
 	qtractorPluginType *pType = m_pPlugin->type();
-	const bool bVstPlugin = (pType->typeHint() == qtractorPluginType::Vst);
+	const bool bVst2Plugin = (pType->typeHint() == qtractorPluginType::Vst2);
 
 	bool bExists  = false;
 	bool bEnabled = (m_pPlugin != nullptr);
@@ -1018,7 +1022,7 @@ void qtractorPluginForm::stabilize (void)
 
 	m_ui.PresetComboBox->setEnabled(bEnabled);
 	m_ui.OpenPresetToolButton->setVisible(
-		bEnabled && (pType->isConfigure() || bVstPlugin));
+		bEnabled && (pType->isConfigure() || bVst2Plugin));
 
 	if (bEnabled) {
 		const QString& sPreset = m_ui.PresetComboBox->currentText();
@@ -1253,7 +1257,14 @@ qtractorPluginParamWidget::qtractorPluginParamWidget (
 		m_pCheckBox->setSubject(m_pParam->subject());
 	//	m_pCheckBox->setChecked(m_pParam->value() > 0.1f);
 		pGridLayout->addWidget(m_pCheckBox, 0, 0);
-		pGridLayout->setColumnStretch(0, 3);
+		pGridLayout->setColumnStretch(0, 2);
+		if (m_pParam->isDisplay()) {
+			m_pDisplay = new qtractorPluginParamDisplay(m_pParam);
+			m_pDisplay->setAlignment(Qt::AlignCenter | Qt::AlignVCenter);
+		//	m_pDisplay->setText(m_pParam->display());
+			m_pDisplay->setMinimumWidth(64);
+			pGridLayout->addWidget(m_pDisplay, 0, 2);
+		}
 	} else {
 		QLabel *pLabel = new QLabel(/*this*/);
 		pLabel->setText(m_pParam->name() + ':');
@@ -1302,7 +1313,7 @@ qtractorPluginParamWidget::qtractorPluginParamWidget (
 			pGridLayout->setColumnStretch(1, 2);
 			if (m_pParam->isDisplay()) {
 				m_pDisplay = new qtractorPluginParamDisplay(m_pParam);
-				m_pDisplay->setAlignment(Qt::AlignLeft | Qt::AlignVCenter);
+				m_pDisplay->setAlignment(Qt::AlignCenter | Qt::AlignVCenter);
 			//	m_pDisplay->setText(m_pParam->display());
 				m_pDisplay->setMinimumWidth(64);
 				pGridLayout->addWidget(m_pDisplay, 0, 2);
