@@ -1,7 +1,7 @@
 // qtractorPluginSelectForm.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2021, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2022, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -60,14 +60,18 @@ qtractorPluginSelectForm::qtractorPluginSelectForm ( QWidget *pParent )
 	m_ui.PluginTypeComboBox->addItem(
 		qtractorPluginType::textFromHint(qtractorPluginType::Dssi));
 #endif
-#ifdef CONFIG_VST
+#ifdef CONFIG_VST2
 	m_ui.PluginTypeComboBox->addItem(
-		qtractorPluginType::textFromHint(qtractorPluginType::Vst));
+		qtractorPluginType::textFromHint(qtractorPluginType::Vst2));
 #endif
 #ifdef CONFIG_VST3
 	m_ui.PluginTypeComboBox->addItem(
 		qtractorPluginType::textFromHint(qtractorPluginType::Vst3));
 #endif
+#ifdef CONFIG_CLAP
+	m_ui.PluginTypeComboBox->addItem(
+		qtractorPluginType::textFromHint(qtractorPluginType::Clap));
+#endif
 #ifdef CONFIG_LV2
 	m_ui.PluginTypeComboBox->addItem(
 		qtractorPluginType::textFromHint(qtractorPluginType::Lv2));
