@@ -509,6 +509,12 @@ unsigned short qtractorSession::beatType (void) const
 // Resolution accessors.
 void qtractorSession::setTicksPerBeat ( unsigned short iTicksPerBeat )
 {
+	if (iTicksPerBeat < qtractorTimeScale::TICKS_PER_BEAT_MIN)
+		iTicksPerBeat = qtractorTimeScale::TICKS_PER_BEAT_MIN;
+	else
+	if (iTicksPerBeat > qtractorTimeScale::TICKS_PER_BEAT_MAX)
+		iTicksPerBeat = qtractorTimeScale::TICKS_PER_BEAT_MAX;
+
 	m_props.timeScale.setTicksPerBeat(iTicksPerBeat);
 }
 
@@ -710,14 +716,14 @@ unsigned long qtractorSession::locateFromFrame ( unsigned long iFrame ) const
 
 
 // Song position pointer (SPP=MIDI beats) to frame converters.
-unsigned long qtractorSession::frameFromSongPos ( unsigned short iSongPos )
+unsigned long qtractorSession::frameFromSongPos ( unsigned int iSongPos )
 {
-	return frameFromTick((iSongPos * ticksPerBeat()) >> 2);
+	return frameFromTick((iSongPos * qtractorTimeScale::TICKS_PER_BEAT_HRQ) >> 2);
 }
 
-unsigned short qtractorSession::songPosFromFrame ( unsigned long iFrame )
+unsigned int qtractorSession::songPosFromFrame ( unsigned long iFrame )
 {
-	return ((tickFromFrame(iFrame) << 2) / ticksPerBeat());
+	return ((tickFromFrame(iFrame) << 2) / qtractorTimeScale::TICKS_PER_BEAT_HRQ);
 }
 
 
@@ -1328,9 +1334,12 @@ void qtractorSession::setPlayHead ( unsigned long iPlayHead )
 
 	seek(iPlayHead, true);
 
-	// Sync all track automation...
-	if (!bPlaying)
+	if (!bPlaying) {
+		// Update time(base)/BBT info...
+		m_pAudioEngine->updateTimeInfo(iPlayHead);
+		// Sync all track automation...
 		process_curve(iPlayHead);
+	}
 
 	setPlaying(bPlaying);
 	unlock();
@@ -1365,9 +1374,12 @@ void qtractorSession::setPlayHeadEx ( unsigned long iPlayHead )
 		m_pAudioEngine->resetAllMonitors();
 		// Make sure we have an actual session cursor...
 		m_pAudioEngine->resetMetro();
+	} else {
+		// Update time(base)/BBT info...
+		m_pAudioEngine->updateTimeInfo(iPlayHead);
+		// Sync all track automation...
+		process_curve(iPlayHead);
 	}
-	// Sync all track automation...
-	else process_curve(iPlayHead);
 
 	m_pMidiEngine->setPlaying(bPlaying);
 
@@ -2264,8 +2276,8 @@ bool qtractorSession::loadElement (
 						= eMarker.attribute("frame").toULong();
 					QString sText;
 					QColor rgbColor = Qt::darkGray;
-					int iAccidentals = 0;
-					int iMode = 0;
+					int iAccidentals = qtractorTimeScale::MinAccidentals;
+					int iMode = -1;
 					for (QDomNode nItem = eMarker.firstChild();
 							!nItem.isNull();
 								nItem = nItem.nextSibling()) {
@@ -2288,7 +2300,7 @@ bool qtractorSession::loadElement (
 							iFrame, sText, rgbColor);
 					}
 					// Or/and key-signature...
-					if (iAccidentals || iMode) {
+					if (qtractorTimeScale::isKeySignature(iAccidentals, iMode)) {
 						qtractorSession::timeScale()->addKeySignature(
 							iFrame, iAccidentals, iMode);
 					}
@@ -2482,7 +2494,8 @@ bool qtractorSession::saveElement (
 				pDocument->saveTextElement("text", pMarker->text, &eMarker);
 				pDocument->saveTextElement("color", pMarker->color.name(), &eMarker);
 			}
-			if (pMarker->accidentals || pMarker->mode) {
+			if (qtractorTimeScale::isKeySignature(
+					pMarker->accidentals, pMarker->mode)) {
 				pDocument->saveTextElement("accidentals",
 					QString::number(pMarker->accidentals), &eMarker);
 				pDocument->saveTextElement("mode",
