@@ -1,7 +1,7 @@
 // qtractorThumbView.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2020, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2022, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -332,10 +332,16 @@ void qtractorThumbView::setPlayHeadX ( int iPlayHeadX )
 	if (pTracks == nullptr)
 		return;
 
-	const int f2 = 1 + (m_iContentsLength / w);
-	pSession->setPlayHead(f2 * iPlayHeadX);
+	qtractorTrackView *pTrackView = pTracks->trackView();
+	if (pTrackView == nullptr)
+		return;
 
-	pTracks->trackView()->setSyncViewHoldOn(false);
+	const int f2 = 1 + (m_iContentsLength / w);
+	const unsigned long iPlayHead = f2 * iPlayHeadX;
+	pSession->setPlayHead(iPlayHead);
+
+	pTrackView->setPlayHeadAutoBackward(iPlayHead);
+	pTrackView->setSyncViewHoldOn(false);
 }
 
 
@@ -361,10 +367,6 @@ void qtractorThumbView::paintEvent ( QPaintEvent *pPaintEvent )
 	if (pMainForm == nullptr)
 		return;
 
-	qtractorTracks *pTracks = pMainForm->tracks();
-	if (pTracks == nullptr)
-		return;
-
 	const int f2 = 1 + (m_iContentsLength / w);
 	int x2;
 
@@ -389,6 +391,20 @@ void qtractorThumbView::paintEvent ( QPaintEvent *pPaintEvent )
 		painter.setPen(Qt::red);
 		painter.drawLine(x2, 0, x2, h);
 	}
+
+	// Shade-out what's not in view...
+	if (m_pRubberBand) {
+		const QColor rgba(0, 0, 0, 96);
+		const QRect& rect2 = m_pRubberBand->geometry();
+		if (rect2.left() > rect.left())
+			painter.fillRect(
+				rect.left(), rect.top(),
+				rect2.left() - rect.left(), rect.height(), rgba);
+		if (rect2.right() < rect.right() + 1)
+			painter.fillRect(
+				rect2.right() + 1, rect.top(),
+				rect.right() - rect2.right(), rect.height(), rgba);
+	}
 }
 
 
