@@ -1,7 +1,7 @@
 // qtractorTimeScaleForm.h
 //
 /****************************************************************************
-   Copyright (C) 2005-2021, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2022, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -42,6 +42,8 @@ public:
 
 	// Constructor.
 	qtractorTimeScaleForm(QWidget *pParent = nullptr);
+	// Destructor.
+	~qtractorTimeScaleForm();
 
 	void setTimeScale(qtractorTimeScale *pTimeScale);
 	qtractorTimeScale *timeScale() const;
@@ -69,6 +71,7 @@ protected slots:
 	void barChanged(int);
 	void timeChanged(unsigned long);
 	void tempoChanged();
+	void accidentalsChanged(int);
 	void modeChanged(int);
 	void changed();
 
