@@ -1,7 +1,7 @@
 // qtractorTrackCommand.cpp
 //
 /****************************************************************************
-   Copyright (C) 2005-2021, rncbc aka Rui Nuno Capela. All rights reserved.
+   Copyright (C) 2005-2022, rncbc aka Rui Nuno Capela. All rights reserved.
 
    This program is free software; you can redistribute it and/or
    modify it under the terms of the GNU General Public License
@@ -740,8 +740,10 @@ qtractorEditTrackCommand::qtractorEditTrackCommand (
 	// Check whether we'll need to re-open the track...
 	const qtractorTrack::Properties& old_props = pTrack->properties();
 	m_bReopen = (
-		old_props.inputBusName  != props.inputBusName ||
-		old_props.outputBusName != props.outputBusName);
+		old_props.inputBusName  != props.inputBusName  ||
+		old_props.outputBusName != props.outputBusName ||
+		( old_props.pluginListLatency && !props.pluginListLatency) ||
+		(!old_props.pluginListLatency &&  props.pluginListLatency));
 }
 
 
@@ -870,24 +872,22 @@ qtractorTrackStateCommand::qtractorTrackStateCommand ( qtractorTrack *pTrack,
 		break;
 	}
 
-	// Toggle/update all other?
-	if (m_toolType != qtractorTrack::Record) {
-		qtractorMainForm *pMainForm = qtractorMainForm::getInstance();
-		if (pMainForm) {
-			qtractorTracks *pTracks = pMainForm->tracks();
-			if (pTracks) {
-				const Qt::KeyboardModifiers& modifiers
-					= QApplication::keyboardModifiers();
-				const bool bAllTracks
-					= (modifiers & (Qt::ShiftModifier | Qt::ControlModifier));
-				if (modifiers & Qt::ControlModifier)
-					bOn = !bOn;
-				const QList<qtractorTrack *>& tracks
-					= pTracks->trackList()->selectedTracks(track(), bAllTracks);
-				QListIterator<qtractorTrack *> iter(tracks);
-				while (iter.hasNext())
-					m_tracks.append(new TrackItem(iter.next(), bOn));
-			}
+	// Toggle/update all othera?
+	qtractorMainForm *pMainForm = qtractorMainForm::getInstance();
+	if (pMainForm) {
+		qtractorTracks *pTracks = pMainForm->tracks();
+		if (pTracks) {
+			const Qt::KeyboardModifiers& modifiers
+				= QApplication::keyboardModifiers();
+			const bool bAllTracks
+				= (modifiers & (Qt::ShiftModifier | Qt::ControlModifier));
+			if (modifiers & Qt::ControlModifier)
+				bOn = !bOn;
+			const QList<qtractorTrack *>& tracks
+				= pTracks->trackList()->selectedTracks(track(), bAllTracks);
+			QListIterator<qtractorTrack *> iter(tracks);
+			while (iter.hasNext())
+				m_tracks.append(new TrackItem(iter.next(), bOn));
 		}
 	}
 
@@ -927,7 +927,7 @@ bool qtractorTrackStateCommand::redo (void)
 	case qtractorTrack::Record:
 		scmd = qtractorMmcEvent::TRACK_RECORD;
 		ccmd = qtractorMidiControl::TRACK_RECORD;
-		// Special stuffing if currently recording at first place...
+		// Special stuffing if currently recording in first place...
 		bOn = pTrack->isRecord();
 		if (bOn && !m_bOn
 			&& m_pClipCommand == nullptr && m_iRecordCount == 0) {
@@ -996,14 +996,19 @@ bool qtractorTrackStateCommand::redo (void)
 			TrackItem *pTrackItem = iter.next();
 			pTrack = pTrackItem->track;
 			bOn = false;
-			if (m_toolType == qtractorTrack::Mute) {
+			switch (m_toolType) {
+			case qtractorTrack::Record:
+				bOn = pTrack->isRecord();
+				pTrack->setRecord(pTrackItem->on);
+				break;
+			case qtractorTrack::Mute:
 				bOn = pTrack->isMute();
 				pTrack->setMute(pTrackItem->on);
-			}
-			else
-			if (m_toolType == qtractorTrack::Solo) {
+				break;
+			case qtractorTrack::Solo:
 				bOn = pTrack->isSolo();
 				pTrack->setSolo(pTrackItem->on);
+				break;
 			}
 			// Send MMC MASKED_WRITE command...
 			iTrack = pTrackList->trackRow(pTrack);
