@@ -522,7 +522,7 @@ bool qtractorTracks::newClip (void)
 			const unsigned long iClipStartTime
 				= pSession->tickFromFrame(iClipStart);
 			const unsigned long iClipLengthTime
-				= pSession->ticksPerBeat() * pSession->beatsPerBar();
+				= qtractorTimeScale::TICKS_PER_BEAT_HRQ * pSession->beatsPerBar();
 			pClip->setClipLength(pSession->frameFromTickRange(
 				iClipStartTime, iClipStartTime + iClipLengthTime));
 		}
@@ -1561,9 +1561,8 @@ bool qtractorTracks::mergeExportMidiClips ( qtractorClipCommand *pClipCommand )
 	}
 
 	// Write SMF header...
-	const unsigned short iTicksPerBeat = pSession->ticksPerBeat();
 	const unsigned short iTracks = (iFormat == 0 ? 1 : 2);
-	if (!file.writeHeader(iFormat, iTracks, iTicksPerBeat)) {
+	if (!file.writeHeader(iFormat, iTracks, pSession->ticksPerBeat())) {
 		QApplication::restoreOverrideCursor();
 		return false;
 	}
@@ -1610,7 +1609,7 @@ bool qtractorTracks::mergeExportMidiClips ( qtractorClipCommand *pClipCommand )
 		file.writeTrack(nullptr);
 
 	// Setup merge sequence...
-	qtractorMidiSequence seq(pTrack->trackName(), 0, iTicksPerBeat);
+	qtractorMidiSequence seq(pTrack->trackName(), 0, qtractorTimeScale::TICKS_PER_BEAT_HRQ);
 	seq.setChannel(pTrack->midiChannel());
 	seq.setBankSelMethod(pTrack->midiBankSelMethod());
 	seq.setBank(pTrack->midiBank());
@@ -2610,10 +2609,6 @@ bool qtractorTracks::addTrack (void)
 	if (pSession == nullptr)
 		return false;
 
-	qtractorMainForm *pMainForm = qtractorMainForm::getInstance();
-	if (pMainForm == nullptr)
-		return false;
-
 	// Create a new track right away...
 	const int iTrack = pSession->tracks().count() + 1;
 	const QColor& color = qtractorTrack::trackColor(iTrack);
@@ -2625,7 +2620,11 @@ bool qtractorTracks::addTrack (void)
 	pTrack->setForeground(color.darker());
 
 	// Open dialog for settings...
-	qtractorTrackForm trackForm(pMainForm);
+	QWidget *pParent = QApplication::activeWindow();
+	if (pParent == nullptr)
+		pParent = static_cast<QWidget *> (qtractorMainForm::getInstance());
+
+	qtractorTrackForm trackForm(pParent);
 	trackForm.setTrack(pTrack);
 	if (!trackForm.exec()) {
 		delete pTrack;
@@ -2699,10 +2698,6 @@ bool qtractorTracks::editTrack ( qtractorTrack *pTrack )
 	if (pSession == nullptr)
 		return false;
 
-	qtractorMainForm *pMainForm = qtractorMainForm::getInstance();
-	if (pMainForm == nullptr)
-		return false;
-
 	// Get the list view item reference of the intended track...
 	if (pTrack == nullptr)
 		pTrack = currentTrack();
@@ -2714,7 +2709,11 @@ bool qtractorTracks::editTrack ( qtractorTrack *pTrack )
 		return false;
 
 	// Open dialog for settings...
-	qtractorTrackForm trackForm(pMainForm);
+	QWidget *pParent = QApplication::activeWindow();
+	if (pParent == nullptr)
+		pParent = static_cast<QWidget *> (qtractorMainForm::getInstance());
+
+	qtractorTrackForm trackForm(pParent);
 	trackForm.setTrack(pTrack);
 	if (!trackForm.exec())
 		return false;
